pub struct Epoch(/* private fields */);Expand description
BABE epoch information
Implementations
Sourceimpl Epoch
impl Epoch
Sourcepub fn genesis(genesis_config: &BabeConfiguration, slot: Slot) -> Epoch
pub fn genesis(genesis_config: &BabeConfiguration, slot: Slot) -> Epoch
Create the genesis epoch (epoch #0).
This is defined to start at the slot of the first block, so that has to be provided.
Sourcepub fn clone_for_slot(&self, slot: Slot) -> Epoch
pub fn clone_for_slot(&self, slot: Slot) -> Epoch
Clone and tweak epoch information to refer to the specified slot.
All the information which depends on the slot value is recomputed and assigned to the returned epoch instance.
The slot must be greater than or equal the original epoch start slot,
if is less this operation is equivalent to a simple clone.